@@ -21,6 +21,7 @@
 #
 
 from PyQt5 import QtCore, QtWidgets, QtGui, Qt  # pylint: disable=import-error
+import argparse
 import os
 import os.path
 import logging
@@ -38,6 +39,17 @@ from qubesadmin.backup import restore
 
 
 # pylint: disable=too-few-public-methods
+def parse_args() -> None:
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+            '--log', action='store', default='INFO',
+            choices=['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL'],
+            help='Provide logging level. Values: DEBUG, INFO, '
+            'INFO (default), ERROR, CRITICAL')
+    args = parser.parse_args()
+    return args
+
+
 class RestoreThread(QtCore.QThread):
     def __init__(self, backup_restore, vms_to_restore):
         QtCore.QThread.__init__(self)
@@ -57,7 +69,8 @@ class RestoreThread(QtCore.QThread):
         except Exception as ex:  # pylint: disable=broad-except
             err_msg.append(str(ex))
             err_msg.append(
-                self.tr("Partially restored files left in /var/tmp/restore_*, "
+                self.tr("Partially restored files left in "
+                        "~/QubesIncoming/backup#restore-*, "
                         "investigate them and/or clean them up"))
         if err_msg:
             self.msg = '<br />'.join(err_msg)
@@ -70,6 +83,7 @@ class RestoreThread(QtCore.QThread):
 
 class RestoreVMsWindow(ui_restoredlg.Ui_Restore, QtWidgets.QWizard):
     def __init__(self, qt_app, qubes_app, parent=None):
+        cliargs = parse_args()
         super().__init__(parent)
 
         self.qt_app = qt_app
@@ -88,7 +102,7 @@ class RestoreVMsWindow(ui_restoredlg.Ui_Restore, QtWidgets.QWizard):
         handler = logging.handlers.QueueHandler(self.feedback_queue)
         logger = logging.getLogger('qubesadmin.backup')
         logger.addHandler(handler)
-        logger.setLevel(logging.INFO)
+        logger.setLevel(cliargs.log)
 
         self.backup_restore = None
         self.target_appvm = None
@@ -114,6 +128,8 @@ class RestoreVMsWindow(ui_restoredlg.Ui_Restore, QtWidgets.QWizard):
         backup_utils.fill_appvms_list(self)
 
         self.passwd_show_button.pressed.connect(self.show_hide_password)
+        self.passphrase_line_edit.returnPressed.connect(
+                self.button(QtWidgets.QWizard.NextButton).click)
 
     def show_hide_password(self):
         if self.passwd_show_button.isChecked():
@@ -234,12 +250,12 @@ class RestoreVMsWindow(ui_restoredlg.Ui_Restore, QtWidgets.QWizard):
         self.progress_bar.setValue(100)
 
         if self.thread.msg:
-            QtWidgets.QMessageBox.warning(
-                self,
-                self.tr("Restore qubes"),
-                self.tr(self.thread.msg))
-
-        if self.thread.msg:
+            messagebox = (
+                QtWidgets.QMessageBox.information
+                if "successful" in self.thread.msg
+                else QtWidgets.QMessageBox.warning
+            )
+            messagebox(self, self.tr("Restore qubes"), self.tr(self.thread.msg))
             self.append_output(self.thread.msg)
 
         if self.showFileDialog.isChecked():
