@@ -28,6 +28,7 @@ import re
 import subprocess
 import sys
 import traceback
+import datetime
 from qubesadmin.tools import QubesArgumentParser
 from qubesadmin import devices
 from qubesadmin import utils as admin_utils
@@ -138,11 +139,12 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         ('services', 5),
         ))
 
-    def __init__(self, vm, init_page="basic", qapp=None, qubesapp=None,
+    # pylint: disable=too-many-positional-arguments
+    def __init__(self, vm_name, init_page="basic", qapp=None, qubesapp=None,
                  parent=None):
         super().__init__(parent)
 
-        self.vm = vm
+        self.vm = qubesapp.domains[vm_name]
         self.qapp = qapp
         self.qubesapp = qubesapp
         self.threads_list = []
@@ -188,7 +190,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         if self.tabWidget.isTabEnabled(self.tabs_indices['firewall']):
             model = firewall.QubesFirewallRulesModel()
             try:
-                model.set_vm(vm)
+                model.set_vm(self.vm)
                 self.set_fw_model(model)
                 self.firewall_modified_outside_label.setVisible(False)
             except firewall.FirewallModifiedOutsideError:
@@ -348,8 +350,13 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         return ret
 
     def check_network_availability(self):
-        netvm = getattr(self.vm, 'netvm', None)
-        provides_network = getattr(self.vm, 'provides_network', False)
+        # this should attempt to use whatever is currently selected, not VM
+        # settings
+        if self.netVM.currentData() == qubesadmin.DEFAULT:
+            netvm = self.vm.property_get_default('netvm')
+        else:
+            netvm = self.netVM.currentData()
+        provides_network = self.provides_network_checkbox.isChecked()
 
         self.no_netvm_label.setVisible(netvm is None and not provides_network)
 
@@ -452,6 +459,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
         self.netVM.currentIndexChanged.connect(self.check_warn_dispvmnetvm)
         self.netVM.currentIndexChanged.connect(self.check_warn_templatenetvm)
+        self.netVM.currentIndexChanged.connect(self.check_network_availability)
 
         try:
             self.include_in_backups.setChecked(self.vm.include_in_backups)
@@ -544,7 +552,6 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
     def __apply_basic_tab__(self):
         msg = []
-
         # vm label changed
         try:
             if utils.did_widget_selection_change(self.vmlabel):
@@ -943,7 +950,8 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
     def enable_seamless(self):
         try:
             self.vm.run_service_for_stdio("qubes.SetGuiMode", input=b'SEAMLESS')
-        except qubesadmin.exc.QubesException as ex:
+        except (qubesadmin.exc.QubesException,
+                subprocess.CalledProcessError) as ex:
             QtWidgets.QMessageBox.warning(
                 self,
                 self.tr("Failed to set seamless mode"),
@@ -953,7 +961,8 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         try:
             self.vm.run_service_for_stdio("qubes.SetGuiMode",
                                           input=b'FULLSCREEN')
-        except qubesadmin.exc.QubesException as ex:
+        except (qubesadmin.exc.QubesException,
+                subprocess.CalledProcessError) as ex:
             QtWidgets.QMessageBox.warning(
                 self,
                 self.tr("Failed to set fullscreen mode"),
@@ -1074,7 +1083,8 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
     def boot_from_cdrom_button_pressed(self):
         boot_dialog = bootfromdevice.VMBootFromDeviceWindow(
-                self.vm.name, self.qapp, self.qubesapp, self)
+                vm=self.vm.name, qapp=self.qapp, qubesapp=self.qubesapp,
+                parent=self)
         if boot_dialog.exec_():
             self.save_and_apply()
             qvm_start.main(
@@ -1316,7 +1326,8 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
     def strict_reset_button_pressed(self):
         device_list_window = device_list.PCIDeviceListWindow(
-            self.vm, self.qapp, self.dev_list, self.new_strict_reset_list, self)
+            vm=self.vm, qapp=self.qapp, dev_list=self.dev_list,
+            no_strict_reset_list=self.new_strict_reset_list, parent=self)
         device_list_window.exec()
 
     ######## applications tab
@@ -1434,12 +1445,13 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             for i in range(self.services_list.count()):
                 item = self.services_list.item(i)
                 self.new_srv_dict[str(item.text())] = \
-                    item.checkState() == ui_settingsdlg.QtCore.Qt.Checked
+                    item.checkState() == QtCore.Qt.Checked
 
             for service, v in self.new_srv_dict.items():
                 feature = SERVICE_PREFIX + service
-                if v != self.vm.features.get(feature, object()):
-                    self.vm.features[feature] = v
+                val = '1' if v else ''
+                if val != self.vm.features.get(feature, object()):
+                    self.vm.features[feature] = val
 
             for feature in self.vm.features:
                 if not feature.startswith(SERVICE_PREFIX) or \
@@ -1465,7 +1477,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         if model.temp_full_access_expire_time:
             self.temp_full_access.setChecked(True)
             expire_time = model.temp_full_access_expire_time - \
-                          firewall.datetime.datetime.now().timestamp()
+                datetime.datetime.now().timestamp()
             self.temp_full_access_time.setValue(int(expire_time / 60))
 
     def disable_all_fw_conf(self):
@@ -1499,7 +1511,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             self.policy_deny_radio_button.isChecked())
 
     def new_rule_button_pressed(self):
-        dialog = firewall.NewFwRuleDlg()
+        dialog = firewall.NewFwRuleDlg(parent=self)
         self.fw_model.run_rule_dialog(dialog)
 
     def edit_rule_button_pressed(self):
@@ -1507,7 +1519,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         selected = self.rulesTreeView.selectedIndexes()
 
         if selected:
-            dialog = firewall.NewFwRuleDlg()
+            dialog = firewall.NewFwRuleDlg(parent=self)
             dialog.set_ok_state(True)
             row = self.rulesTreeView.selectedIndexes().pop().row()
             self.fw_model.populate_edit_dialog(dialog, row)
@@ -1540,7 +1552,8 @@ def main(args=None):
               "and qvm-features to change properties of an AdminVM")
         return 1
 
-    utils.run_synchronous(functools.partial(VMSettingsWindow, vm, args.tab))
+    utils.run_synchronous(functools.partial(VMSettingsWindow, vm.name,
+                                            args.tab))
 
 
 if __name__ == "__main__":
