@@ -29,11 +29,11 @@ import traceback
 import asyncio
 from contextlib import suppress
 import sys
-import qasync
 from qubesadmin import events
 from qubesadmin import exc
 
 from PyQt5 import QtWidgets, QtCore, QtGui  # pylint: disable=import-error
+import qasync
 
 
 # important usage note: which initialize_widget should I use?
@@ -74,21 +74,21 @@ def translate(string):
 
 
 class SizeSpinBox(QtWidgets.QSpinBox):
-    """A SpinBox subclass with extended handling for sizes in MB and GB"""
+    """A SpinBox subclass with extended handling for sizes in MiB and GiB"""
     # pylint: disable=invalid-name
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.pattern = r'(\d+\.?\d?) ?(GB|MB)'
+        self.pattern = r'(\d+\.?\d?) ?(GiB|MiB)'
         self.regex = re.compile(self.pattern)
         self.validator = QtGui.QRegExpValidator(QtCore.QRegExp(
             self.pattern), self)
 
     def textFromValue(self, v: int) -> str:
         if v > 1024:
-            return '{:.1f} GB'.format(v / 1024)
+            return '{:.1f} GiB'.format(v / 1024)
 
-        return '{} MB'.format(v)
+        return '{} MiB'.format(v)
 
     def validate(self, text: str, pos: int):
         return self.validator.validate(text, pos)
@@ -96,7 +96,7 @@ class SizeSpinBox(QtWidgets.QSpinBox):
     def valueFromText(self, text: str) -> int:
         value, unit = self.regex.fullmatch(text.strip()).groups()
 
-        if unit == 'GB':
+        if unit == 'GiB':
             multiplier = 1024
         else:
             multiplier = 1
@@ -175,9 +175,9 @@ def initialize_widget(widget, choices, selected_value=None,
                            widget.currentText() + translate(" (current)"))
 
 
-def initialize_widget_for_property(
-        widget, choices, holder, property_name, allow_default=False,
-        icon_getter=None, add_current_label=True):
+def initialize_widget_for_property(*, widget, choices, holder, property_name,
+                                   allow_default=False, icon_getter=None,
+                                   add_current_label=True):
     """
     populates widget (ListBox or ComboBox) with items, based on a listed
     property. Supports discovering the system default for the given property
@@ -226,7 +226,7 @@ def initialize_widget_for_property(
 
 # TODO: improvement: add optional icon support
 def initialize_widget_with_vms(
-        widget, qubes_app, filter_function=(lambda x: True),
+        *, widget, qubes_app, filter_function=(lambda x: True),
         allow_none=False, holder=None, property_name=None,
         allow_default=False, allow_internal=False):
     """
@@ -270,7 +270,7 @@ def initialize_widget_with_vms(
 
 
 def initialize_widget_with_default(
-        widget, choices, add_none=False, add_qubes_default=False,
+        *, widget, choices, add_none=False, add_qubes_default=False,
         mark_existing_as_default=False, default_value=None):
     """
     populates widget (ListBox or ComboBox) with items. Used when there is no
@@ -330,7 +330,7 @@ def initialize_widget_with_default(
 
 
 def initialize_widget_with_kernels(
-        widget, qubes_app, allow_none=False, holder=None,
+        *, widget, qubes_app, allow_none=False, holder=None,
         property_name=None, allow_default=False):
     """
     populates widget (ListBox or ComboBox) with kernel items, based on a given
@@ -526,18 +526,21 @@ def run_asynchronous(window_class):
 
     loop = qasync.QEventLoop(qt_app)
     asyncio.set_event_loop(loop)
-    dispatcher = events.EventsDispatcher(qubes_app)
 
-    window = window_class(qt_app, qubes_app, dispatcher)
+    async def setup():
+        dispatcher = events.EventsDispatcher(qubes_app)
 
-    if hasattr(window, "setup_application"):
-        window.setup_application()
+        window = window_class(qt_app, qubes_app, dispatcher)
 
-    window.show()
+        if hasattr(window, "setup_application"):
+            window.setup_application()
+
+        window.show()
+
+        await dispatcher.listen_for_events()
 
     try:
-        loop.run_until_complete(
-            asyncio.ensure_future(dispatcher.listen_for_events()))
+        loop.run_until_complete(asyncio.ensure_future(setup()))
     except asyncio.CancelledError:
         pass
     except Exception:  # pylint: disable=broad-except
